==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/webpubsub/kotlin/inputs/LiveTraceCategoryArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.webpubsub.kotlin.inputs

import com.pulumi.azurenative.webpubsub.inputs.LiveTraceCategoryArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Live trace category configuration of a Microsoft.SignalRService resource.
 * @property enabled Indicates whether or the live trace category is enabled.
 * Available values: true, false.
 * Case insensitive.
 * @property name Gets or sets the live trace category's name.
 * Available values: ConnectivityLogs, MessagingLogs.
 * Case insensitive.
 */
public data class LiveTraceCategoryArgs(
    public val enabled: Output<String>? = null,
    public val name: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.webpubsub.inputs.LiveTraceCategoryArgs> {
    override fun toJava(): com.pulumi.azurenative.webpubsub.inputs.LiveTraceCategoryArgs =
        com.pulumi.azurenative.webpubsub.inputs.LiveTraceCategoryArgs.builder()
            .enabled(enabled?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LiveTraceCategoryArgs].
 */
@PulumiTagMarker
public class LiveTraceCategoryArgsBuilder internal constructor() {
    private var enabled: Output<String>? = null

    private var name: Output<String>? = null

    /**
     * @param value Indicates whether or the live trace category is enabled.
     * Available values: true, false.
     * Case insensitive.
     */
    @JvmName("gmxbivsfxepgivrq")
    public suspend fun enabled(`value`: Output<String>) {
        this.enabled = value
    }

    /**
     * @param value Gets or sets the live trace category's name.
     * Available values: ConnectivityLogs, MessagingLogs.
     * Case insensitive.
     */
    @JvmName("vvmssstmkbhslthy")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Indicates whether or the live trace category is enabled.
     * Available values: true, false.
     * Case insensitive.
     */
    @JvmName("astvwvgmslforfpg")
    public suspend fun enabled(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value Gets or sets the live trace category's name.
     * Available values: ConnectivityLogs, MessagingLogs.
     * Case insensitive.
     */
    @JvmName("vsfamxrqbasctkdb")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): LiveTraceCategoryArgs = LiveTraceCategoryArgs(
        enabled = enabled,
        name = name,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/webpubsub/kotlin/inputs/LiveTraceCategoryArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.webpubsub.kotlin.inputs

import com.pulumi.azurenative.webpubsub.inputs.LiveTraceCategoryArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Live trace category configuration of a Microsoft.SignalRService resource.
 * @property enabled Indicates whether or the live trace category is enabled.
 * Available values: true, false.
 * Case insensitive.
 * @property name Gets or sets the live trace category's name.
 * Available values: ConnectivityLogs, MessagingLogs.
 * Case insensitive.
 */
public data class LiveTraceCategoryArgs(
    public val enabled: Output<String>? = null,
    public val name: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.webpubsub.inputs.LiveTraceCategoryArgs> {
    override fun toJava(): com.pulumi.azurenative.webpubsub.inputs.LiveTraceCategoryArgs =
        com.pulumi.azurenative.webpubsub.inputs.LiveTraceCategoryArgs.builder()
            .enabled(enabled?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LiveTraceCategoryArgs].
 */
@PulumiTagMarker
public class LiveTraceCategoryArgsBuilder internal constructor() {
    private var enabled: Output<String>? = null

    private var name: Output<String>? = null

    /**
     * @param value Indicates whether or the live trace category is enabled.
     * Available values: true, false.
     * Case insensitive.
     */
    @JvmName("pvunaaniiqodymke")
    public suspend fun enabled(`value`: Output<String>) {
        this.enabled = value
    }

    /**
     * @param value Gets or sets the live trace category's name.
     * Available values: ConnectivityLogs, MessagingLogs.
     * Case insensitive.
     */
    @JvmName("ircbdeomohaexvdv")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Indicates whether or the live trace category is enabled.
     * Available values: true, false.
     * Case insensitive.
     */
    @JvmName("yutbtfnyedkkdtnu")
    public suspend fun enabled(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value Gets or sets the live trace category's name.
     * Available values: ConnectivityLogs, MessagingLogs.
     * Case insensitive.
     */
    @JvmName("kakyvblmoqxyskou")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): LiveTraceCategoryArgs = LiveTraceCategoryArgs(
        enabled = enabled,
        name = name,
    )
}
